/*
 * TeamStats by Mats Bovin (mats@mbovin.com)
 * v1.3.0 September 2002
 * Copyright (c) 2002 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _LEAGUE_H_
#define _LEAGUE_H_

#include <PalmOS.h>


//
// Typedefs
//
typedef struct {
    DmOpenRef dbRef;
    Int8      winPoints;
    Int8      teamCount;
    Int16     matchCount;
    Int16     playedMatchCount;
    Int8      roundCount;
    Int8      line[4];
    Int8      dbVersion;
    //Int8      tableSortMethod;
    //Int8      favouriteTeam;
} League;


typedef struct {
    Int8     round;
    UInt16   dateYear;  // four digits, eg 2001
    UInt8    dateMonth; // 1-12
    UInt8    dateDay;   // 1-31
    Int8     homeTeam;
    Int8     awayTeam;
    Int8     homeGoals;
    Int8     awayGoals;
    Boolean  isPlayed;
} Match;



//
// Functions
//
League LeagueGetCurrent();
void   LeagueSave(League* league);
void   LeagueSaveTeam(League* league, Int8 teamIndex, Char* teamName);
void   LeagueSaveTeamPoints(League* league, Int8 teamIndex, Int8 points);
void   LeagueAddRound(League* league);
Char*  LeagueGetTeam(League* league, Int8 index);
Int8   LeagueGetTeamPoints(League* league, Int8 teamIndex);
Match  LeagueGetMatch(League* league, Int16 index);
Int8   LeagueGetMatchesInRound(League* league, Int8 round, Int16* matches);
Int8   LeagueGetMatchesForTeam(League* league, Int8 teamIndex, Int8 matches, Int16* matchesForTeam);
Int16  LeagueGetCurrentRound(League* league);
Int16  LeagueUpdateMatchResult(League* league, Int16 matchIndex, Int8 homeGoals, Int8 awayGoals);
void   LeagueGetMatchString(League* league, Int16 matchIndex, Char* matchString);
Int16  LeagueAddMatch(League* league, Match* match, Int8 posInRound);
Int8   LeagueDeleteMatch(League* league, Int8 round, Int16 matchIndex);
void   LeagueDeleteRound(League* league, Int8 round);
Int16  LeagueChangeMatchDate(League* league, Int16 matchIndex, Int16 year, Int16 month, Int16 day);
void   LeagueGetSortedTeamIndexes(League* league, Int16* sortedIndex);

#endif