/*
 * TeamStats by Mats Bovin (mats@mbovin.com)
 * v1.3.0 September 2002
 * Copyright (c) 2002 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <PalmOS.h>
#include "TeamStats.h" /*ToK: Typo corrected*/
#include "rcp.h"
#include "League.h"
#include "Funcs.h"
#include "Stats.h"
#include "Text.h"

// Init form
void InitLeagueForm() {
  InitTop(MODE_LEAGUE);
}


// Free form
void FreeLeagueForm() {
}


// Draws the form.
void DrawLeagueForm() {
  Char buf[20], buf2[10];
  League league = LeagueGetCurrent();
  LeagueStats stats;
  Int16 x1 = 5;
  Int16 x2 = 115;
  Int16 x3 = 153;

  // create the stats to display
  stats = StatsGetLeagueStats(&league);

  // display the stats
  UIDrawCharsLeft(TEXT_LEAGUE_MATCHES_PLAYED, x1, 28);
  StrIToA(buf, stats.matchCount);
  UIDrawCharsRight(buf, x2, 28);

  UIDrawCharsLeft(TEXT_LEAGUE_WON_HOME, x1, 40);
  StrIToA(buf, stats.homeWins);
  UIDrawCharsRight(buf, x2, 40);
  DoubleToPercentStr(stats.homeWinPct, buf2, 1);
  StrPrintF(buf, "(%s)", buf2);
  UIDrawCharsRight(buf, x3, 40);

  UIDrawCharsLeft(TEXT_LEAGUE_DRAWS, x1, 52);
  StrIToA(buf, stats.draws);
  UIDrawCharsRight(buf, x2, 52);
  DoubleToPercentStr(stats.drawPct, buf2, 1);
  StrPrintF(buf, "(%s)", buf2);
  UIDrawCharsRight(buf, x3, 52);

  UIDrawCharsLeft(TEXT_LEAGUE_WON_AWAY, x1, 64);
  StrIToA(buf, stats.awayWins);
  UIDrawCharsRight(buf, x2, 64);
  DoubleToPercentStr(stats.awayWinPct, buf2, 1);
  StrPrintF(buf, "(%s)", buf2);
  UIDrawCharsRight(buf, x3, 64);

  UIDrawCharsLeft(TEXT_LEAGUE_GOALS_SCORED, x1, 78);
  StrIToA(buf, stats.goalCount);
  UIDrawCharsRight(buf, x2, 78);
  DoubleToStr(stats.goalAvg, buf2, 2);
  StrPrintF(buf, "(%s)", buf2);
  UIDrawCharsRight(buf, x3, 78);

  UIDrawCharsLeft(TEXT_LEAGUE_GOALS_HOME, x1, 90);
  StrIToA(buf, stats.homeGoals);
  UIDrawCharsRight(buf, x2, 90);
  DoubleToStr(stats.homeGoalAvg, buf2, 2);
  StrPrintF(buf, "(%s)", buf2);
  UIDrawCharsRight(buf, x3, 90);

  UIDrawCharsLeft(TEXT_LEAGUE_GOALS_AWAY, x1, 102);
  StrIToA(buf, stats.awayGoals);
  UIDrawCharsRight(buf, x2, 102);
  DoubleToStr(stats.awayGoalAvg, buf2, 2);
  StrPrintF(buf, "(%s)", buf2);
  UIDrawCharsRight(buf, x3, 102);

  WinDrawChars(TEXT_LEAGUE_MOST_FREQUENT, 21, x1, 116);
  if(stats.result0.count > -1) {
    StrPrintF(buf, TEXT_LEAGUE_TIMES, stats.result0.homeGoals, stats.result0.awayGoals, stats.result0.count);
    WinDrawChars(buf, StrLen(buf), x2-15, 116);
  }
  if(stats.result1.count > -1) {
    StrPrintF(buf, TEXT_LEAGUE_TIMES, stats.result1.homeGoals, stats.result1.awayGoals, stats.result1.count);
    WinDrawChars(buf, StrLen(buf), x2-15, 128);
  }
  if(stats.result2.count > -1) {
    StrPrintF(buf, TEXT_LEAGUE_TIMES, stats.result2.homeGoals, stats.result2.awayGoals, stats.result2.count);
    WinDrawChars(buf, StrLen(buf), x2-15, 140);
  }
}


// Eventhandler for main form
Boolean LeagueFormEvtHandler(EventPtr event) {
  Boolean handled      = false;
  Boolean updateScreen = false;

  switch (event->eType) {

 // form is opened
  case frmOpenEvent:
    InitLeagueForm();
    updateScreen = true;
    handled = true;
    break;

 // form is closed
  case frmCloseEvent:
    FreeLeagueForm();
    break;

 // form need to be updated
  case frmUpdateEvent:
    updateScreen = true;
    handled = true;
    break;

 // one of the mode buttons were tapped
  case ctlSelectEvent:
    switch(event->data.ctlSelect.controlID) {
      case btnID_table:
        GState.mode = MODE_TABLE;
        FrmGotoForm(formID_table);
        handled = true;
        break;
      case btnID_matches:
        GState.mode = MODE_MATCHES;
        FrmGotoForm(formID_matches);
        handled = true;
        break;
      case btnID_team:
        GState.mode = MODE_TEAM;
        FrmGotoForm(formID_team);
        handled = true;
        break;
    }
    break;

 // drop-down selected
  case popSelectEvent:
    switch(event->data.popSelect.controlID) {
      case popTrigID_league:
        if(event->data.popSelect.selection != GState.currentLeagueIndex) {
          ShowLeague(event->data.popSelect.selection, MODE_LEAGUE, true);
        }
        break;
    }
    break;

  }

 // redraw the screen if needed
  if(updateScreen) {
    FrmDrawForm(FrmGetActiveForm());
    DrawLeagueForm();
  }

  return handled;
}

