/*
 * TeamStats by Mats Bovin (mats@mbovin.com)
 * v1.3.0 September 2002
 * Copyright (c) 2002 Mats Bovin
 *
 * This file is part of TeamStats.
 *
 * TeamStats is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TeamStats is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TeamStats; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _TEAMSTATS_H_
#define _TEAMSTATS_H_

// constants
#define LEAGUENAME_SIZE 17
#define MAX_LEAGUES     20
#define MAX_TEAMS       30

#define MODE_NOLEAGUE 10
#define MODE_TABLE    20
#define MODE_MATCHES  30
#define MODE_TEAM     40
#define MODE_LEAGUE   50

#define TEAM_MODE_TABLE   0
#define TEAM_MODE_MATCHES 1

#define MATCHES_ALL  0
#define MATCHES_HOME 1
#define MATCHES_AWAY 2

#define RESULT_ALL   10
#define RESULT_WON   20
#define RESULT_DRAWN 30
#define RESULT_LOST  40

// macros
#define min(a, b) (((a) < (b)) ? (a) : (b))
#define max(a, b) (((a) > (b)) ? (a) : (b))

#include "League.h"

// data types
typedef struct {
  LocalID localID;
  UInt16  cardNo;
  Char    name[LEAGUENAME_SIZE];
} LeagueDBInfo;

typedef struct {
  Int8 currentLeagueIndex;
  Int8 leagueCount;
  Int8 mode;
  struct {
    Int8 matches;
    Int8 rounds;
    Int8 roundCount;
    Int8 scrollPos;
  } Table;
  struct {
    Int8  round;
    Int16 scrollPos;
  } Match;
  struct {
    Int8  team;
    Int8  matches;
    Int8  mode;
    Int16 scrollPos;
  } Team;
} AppState;

typedef struct {
  Int8 version;
  Char  dbName[LEAGUENAME_SIZE];
  Int8  mode;
  Int8  tableMatches;
  Int8  tableRounds;
  Int8  tableRoundCount;
  Int8  tableScrollPos;
  Int8  matchRound;
  Int16 matchScrollPos;
  Int8  teamTeam;
  Int8  teamMatches;
  Int8  teamMode;
  Int16 teamScrollPos;
} AppInfoBlock;

// Main.c
extern AppState GState;
extern Char*    GLeagueNames[MAX_LEAGUES];

void ShowLeague(Int8 leagueIndex, Int8 startupMode, Boolean initState);
void InitTop(Int8 mode);
Err  CreateDatabase(Char* dbName, League *league);
Err  EditCurrentDatabase(Char* newDBName, League *league);

// TableForm.c
Boolean TableFormEvtHandler(EventPtr event);

// MatchForm.c
Boolean MatchFormEvtHandler(EventPtr event);

// TeamForm.c
Boolean TeamFormEvtHandler(EventPtr event);

// LeagueForm.c
Boolean LeagueFormEvtHandler(EventPtr event);

// Dialogs.c
Boolean CreateLeagueFormEvtHandler(EventPtr event);
Boolean EditLeagueFormEvtHandler(EventPtr event);
Boolean EditTeamsFormEvtHandler(EventPtr event);
Boolean EditFixturesFormEvtHandler(EventPtr event);
Boolean SelectRoundFormEvtHandler(EventPtr event);
Boolean AboutFormEvtHandler(EventPtr event);

#endif